==> mysql-8.0_8.0.19.orig.tar.gz: mysql-8.0.19/client/dump/i_connection_provider.h <==
/*
  Copyright (c) 2015, 2017, Oracle and/or its affiliates. All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef I_CONNECTION_PROVIDER_INCLUDED
#define I_CONNECTION_PROVIDER_INCLUDED

#include <functional>

#include "client/base/message_data.h"
#include "client/base/mysql_query_runner.h"

namespace Mysql {
namespace Tools {
namespace Dump {

class I_connection_provider {
 public:
  virtual ~I_connection_provider() {}
  virtual Mysql::Tools::Base::Mysql_query_runner *get_runner(
      std::function<bool(const Mysql::Tools::Base::Message_data &)>
          *message_handler) = 0;
};

}  // namespace Dump
}  // namespace Tools
}  // namespace Mysql

#endif

==> mysql-8.0_8.0.28.orig.tar.gz: mysql-8.0.28/client/dump/i_connection_provider.h <==
/*
  Copyright (c) 2015, 2021, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef I_CONNECTION_PROVIDER_INCLUDED
#define I_CONNECTION_PROVIDER_INCLUDED

#include <functional>

#include "client/base/message_data.h"
#include "client/base/mysql_query_runner.h"

namespace Mysql {
namespace Tools {
namespace Dump {

class I_connection_provider {
 public:
  virtual ~I_connection_provider() = default;
  virtual Mysql::Tools::Base::Mysql_query_runner *get_runner(
      std::function<bool(const Mysql::Tools::Base::Message_data &)>
          *message_handler) = 0;
};

}  // namespace Dump
}  // namespace Tools
}  // namespace Mysql

#endif
